@@ -27,15 +27,14 @@
 #include "cairo-support.h"
 
 static void
-murrine_draw_inset (cairo_t          *cr,
+murrine_draw_inset (cairo_t *cr,
                     const MurrineRGB *bg_color,
                     double x, double y, double w, double h,
                     double radius, uint8 corners)
 {
-	MurrineRGB shadow;
-	MurrineRGB highlight;
+	MurrineRGB shadow, highlight;
+	radius = MIN (radius, MIN (w/2.0, h/2.0));
 
-	/* not really sure of shading ratios... we will think */
 	murrine_shade (bg_color, 0.74, &shadow);
 	murrine_shade (bg_color, 1.3, &highlight);
 
@@ -84,7 +83,7 @@ murrine_draw_inset (cairo_t          *cr,
 
 static void
 murrine_draw_highlight_and_shade (cairo_t *cr,
-                                  const MurrineColors *colors,
+                                  const MurrineColors    *colors,
                                   const ShadowParameters *widget,
                                   int width, int height, int radius)
 {
@@ -95,6 +94,7 @@ murrine_draw_highlight_and_shade (cairo_t *cr,
 	double y = 1.0;
 	width  -= 3;
 	height -= 3;
+	radius = MIN (radius, MIN ((double)width/2.0, (double)height/2.0));
 
 	if (radius < 0)
 		radius = 0;
@@ -247,12 +247,16 @@ static void
 murrine_draw_entry (cairo_t *cr,
                     const MurrineColors    *colors,
                     const WidgetParameters *widget,
+                    const FocusParameters  *focus,
                     int x, int y, int width, int height)
 {
 	const MurrineRGB *base = &colors->base[widget->state_type];
-	const MurrineRGB *border = &colors->shade[widget->disabled ? 4 : 6];
+	MurrineRGB border = colors->shade[widget->disabled ? 4 : 6];
 	int radius = CLAMP (widget->roundness, 0, 3);
 
+	if (widget->focus)
+		border = focus->color;
+
 	cairo_translate (cr, x+0.5, y+0.5);
 
 	/* Fill the entry's base color */
@@ -266,14 +270,17 @@ murrine_draw_entry (cairo_t *cr,
 	/* Draw the focused border */
 	if (widget->focus)
 	{
+		MurrineRGB focus_shadow;
+		murrine_shade (&border, 1.54, &focus_shadow);
+
 		cairo_rectangle (cr, 2, 2, width-5, height-5);
-		murrine_set_color_rgba (cr, &colors->spot[1], 0.5);
+		murrine_set_color_rgba (cr, &focus_shadow, 0.5);
 		cairo_stroke(cr);
 	}
 	else if (widget->mrn_gradient.gradients)
 	{
 		MurrineRGB shadow;
-		murrine_shade (border, 0.925, &shadow);
+		murrine_shade (&border, 0.925, &shadow);
 
 		cairo_move_to (cr, 2, height-3);
 		cairo_line_to (cr, 2, 2);
@@ -284,14 +291,14 @@ murrine_draw_entry (cairo_t *cr,
 	}
 
 	/* Draw the border */
-	murrine_set_color_rgb (cr, widget->focus ? &colors->spot[2] : border);
+	murrine_set_color_rgb (cr, &border);
 	murrine_rounded_rectangle (cr, 1, 1, width-3, height-3, radius, widget->corners);
 	cairo_stroke (cr);
 }
 
 static void
 murrine_draw_entry_progress (cairo_t *cr,
-                             const MurrineColors *colors,
+                             const MurrineColors    *colors,
                              const WidgetParameters *widget,
                              const EntryProgressParameters *progress,
                              int x, int y, int width, int height)
@@ -1354,7 +1361,7 @@ murrine_draw_menuitem (cairo_t *cr,
 			cairo_fill (cr);
 
 			murrine_set_color_rgba (cr, border, 0.15);
-			murrine_rounded_rectangle (cr, 0.5, 0.5, width-1, height-1, widget->roundness, widget->corners);
+			murrine_rounded_rectangle_closed (cr, 0.5, 0.5, width-1, height-1, widget->roundness, widget->corners);
 			cairo_fill_preserve (cr);
 			break;
 		default:
@@ -1528,7 +1535,7 @@ murrine_draw_scrollbar_slider (cairo_t *cr,
 
 	cairo_save (cr);
 
-	murrine_rounded_rectangle_closed (cr, 1, 1, width-2, height-2, widget->roundness, widget->corners);
+	murrine_rounded_rectangle_closed (cr, 1, 1, width-2, height-2, widget->roundness-1, widget->corners);
 	cairo_clip_preserve (cr);
 
 	murrine_draw_glaze (cr, &fill,
